@@ -5,7 +5,7 @@
  * object level logging, and fully-qualified object names for all DML and DDL
  * statements where possible (See README.md for details).
  *
- * Copyright (c) 2014-2025, PostgreSQL Global Development Group
+ * Copyright (c) 2014-2022, PostgreSQL Global Development Group
  *------------------------------------------------------------------------------
  */
 #include "postgres.h"
@@ -70,7 +70,7 @@ PG_FUNCTION_INFO_V1(pgaudit_sql_drop);
 #define LOG_ALL         (0xFFFFFFFF)    /* All */
 
 /* GUC variable for pgaudit.log, which defines the classes to log. */
-static char *auditLog = NULL;
+char *auditLog = NULL;
 
 /* Bitmap of classes selected */
 static int auditLogBitmap = LOG_NONE;
@@ -97,7 +97,7 @@ static int auditLogBitmap = LOG_NONE;
  * the query are in pg_catalog.  Interactive sessions (eg: psql) can cause
  * a lot of noise in the logs which might be uninteresting.
  */
-static bool auditLogCatalog = true;
+bool auditLogCatalog = true;
 
 /*
  * GUC variable for pgaudit.log_client
@@ -106,7 +106,7 @@ static bool auditLogCatalog = true;
  * setting should generally be left disabled but may be useful for debugging or
  * other purposes.
  */
-static bool auditLogClient = false;
+bool auditLogClient = false;
 
 /*
  * GUC variable for pgaudit.log_level
@@ -115,8 +115,8 @@ static bool auditLogClient = false;
  * at.  The default level is LOG, which goes into the server log but does
  * not go to the client.  Set to NOTICE in the regression tests.
  */
-static char *auditLogLevelString = NULL;
-static int auditLogLevel = LOG;
+char *auditLogLevelString = NULL;
+int auditLogLevel = LOG;
 
 /*
  * GUC variable for pgaudit.log_parameter
@@ -124,7 +124,7 @@ static int auditLogLevel = LOG;
  * Administrators can choose if parameters passed into a statement are
  * included in the audit log.
  */
-static bool auditLogParameter = false;
+bool auditLogParameter = false;
 
 /*
  * GUC variable for pgaudit.log_relation
@@ -133,7 +133,7 @@ static bool auditLogParameter = false;
  * in READ/WRITE class queries.  By default, SESSION logs include the query but
  * do not have a log entry for each relation.
  */
-static bool auditLogRelation = false;
+bool auditLogRelation = false;
 
 /*
  * GUC variable for pgaudit.log_rows
@@ -141,14 +141,14 @@ static bool auditLogRelation = false;
  * Administrators can choose if the rows retrieved or affected by a statement
  * are included in the audit log.
  */
-static bool auditLogRows = false;
+bool auditLogRows = false;
 
 /*
  * GUC variable for pgaudit.log_statement
  *
  * Administrators can choose to not have the full statement text logged.
  */
-static bool auditLogStatement = true;
+bool auditLogStatement = true;
 
 /*
  * GUC variable for pgaudit.log_statement_once
@@ -156,9 +156,9 @@ static bool auditLogStatement = true;
  * Administrators can choose to have the statement run logged only once instead
  * of on every line.  By default, the statement is repeated on every line of
  * the audit log to facilitate searching, but this can cause the log to be
- * unnecessarily bloated in some environments.
+ * unnecessairly bloated in some environments.
  */
-static bool auditLogStatementOnce = false;
+bool auditLogStatementOnce = false;
 
 /*
  * GUC variable for pgaudit.role
@@ -167,7 +167,7 @@ static bool auditLogStatementOnce = false;
  * Object-level auditing uses the privileges which are granted to this role to
  * determine if a statement should be logged.
  */
-static char *auditRole = NULL;
+char *auditRole = NULL;
 
 /*
  * String constants for the audit log fields.
@@ -255,7 +255,7 @@ typedef struct AuditEventStackItem
     MemoryContextCallback contextCallback;
 } AuditEventStackItem;
 
-static AuditEventStackItem *auditEventStack = NULL;
+AuditEventStackItem *auditEventStack = NULL;
 
 /*
  * pgAudit runs queries of its own when using the event trigger system.
@@ -704,7 +704,7 @@ log_audit_event(AuditEventStackItem *stackItem)
     append_valid_csv(&auditStr, stackItem->auditEvent.objectName);
 
     /*
-     * If auditLogStatementOnce is true, then only log the statement and
+     * If auditLogStatmentOnce is true, then only log the statement and
      * parameters if they have not already been logged for this substatement.
      */
     appendStringInfoCharMacro(&auditStr, ',');
@@ -1017,11 +1017,8 @@ log_select_dml(Oid auditOid, List *rangeTabls)
         Oid relNamespaceOid;
         RangeTblEntry *rte = lfirst(lr);
 
-        /*
-         * We only care about tables, and can ignore subqueries etc. Also detect
-         * and skip partitions by checking for missing requiredPerms.
-         */
-        if (rte->rtekind != RTE_RELATION || rte->requiredPerms == 0)
+        /* We only care about tables, and can ignore subqueries etc. */
+        if (rte->rtekind != RTE_RELATION)
             continue;
 
         found = true;
@@ -1029,7 +1026,7 @@ log_select_dml(Oid auditOid, List *rangeTabls)
         /*
          * Don't log if the session user is not a member of the current
          * role.  This prevents contents of security definer functions
-         * from being logged and suppresses foreign key queries unless the
+         * from being logged and supresses foreign key queries unless the
          * session user is the owner of the referenced table.
          */
         if (!is_member_of_role(GetSessionUserId(), GetUserId()))
@@ -1063,7 +1060,7 @@ log_select_dml(Oid auditOid, List *rangeTabls)
         }
 
         /*
-         * We don't have access to the parse tree here, so we have to generate
+         * We don't have access to the parsetree here, so we have to generate
          * the node type, object type, and command tag by decoding
          * rte->requiredPerms and rte->relkind. For updates we also check
          * rellockmode so that only true UPDATE commands (not
@@ -1511,8 +1508,8 @@ pgaudit_ProcessUtility_hook(PlannedStmt *pstmt,
         if (context == PROCESS_UTILITY_TOPLEVEL)
         {
             /*
-             * If the stack is not empty then the only allowed entries are call
-             * statements or open, select, show, and explain cursors
+             * If the stack is not empty then the only allowed entries are open
+             * select, show, and explain cursors
              */
             if (auditEventStack != NULL)
             {
@@ -1522,8 +1519,7 @@ pgaudit_ProcessUtility_hook(PlannedStmt *pstmt,
                 {
                     if (nextItem->auditEvent.commandTag != T_SelectStmt &&
                         nextItem->auditEvent.commandTag != T_VariableShowStmt &&
-                        nextItem->auditEvent.commandTag != T_ExplainStmt &&
-                        nextItem->auditEvent.commandTag != T_CallStmt)
+                        nextItem->auditEvent.commandTag != T_ExplainStmt)
                     {
                         elog(ERROR, "pgaudit stack is not empty");
                     }
@@ -2149,7 +2145,7 @@ _PG_init(void)
 
         "Specifies whether logging will include the statement text and "
         "parameters with the first log entry for a statement/substatement "
-        "combination or with every entry.  Enabling this setting will result "
+        "combination or with every entry.  Disabling this setting will result "
         "in less verbose logging but may make it more difficult to determine "
         "the statement that generated a log entry, though the "
         "statement/substatement pair along with the process id should suffice "
